import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/all_devices/bloc/switch_tabs/switch_tabs_bloc.dart';
import 'package:syncrow_web/pages/routiens/bloc/routine_bloc/routine_bloc.dart';
import 'package:syncrow_web/pages/routiens/widgets/main_routine_view/routine_view_card.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';
import 'package:syncrow_web/utils/helpers/responsice_layout_helper/responsive_layout_helper.dart';

class FetchRoutineScenesAutomation extends StatefulWidget {
  const FetchRoutineScenesAutomation({super.key});

  @override
  State<FetchRoutineScenesAutomation> createState() => _FetchRoutineScenesState();
}

class _FetchRoutineScenesState extends State<FetchRoutineScenesAutomation>
    with HelperResponsiveLayout {
  @override
  void initState() {
    super.initState();
    context.read<RoutineBloc>()
      ..add(const LoadScenes(spaceId, communityId))
      ..add(const LoadAutomation(spaceId));
  }

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<RoutineBloc, RoutineState>(
      builder: (context, state) {
        return state.isLoading
            ? const Center(
                child: CircularProgressIndicator(),
              )
            : SingleChildScrollView(
                child: Padding(
                  padding: const EdgeInsets.symmetric(vertical: 16.0),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      Text(
                        "Scenes (Tab to Run)",
                        style: Theme.of(context).textTheme.titleLarge?.copyWith(
                              color: ColorsManager.grayColor,
                              fontWeight: FontWeight.bold,
                            ),
                      ),
                      const SizedBox(height: 10),
                      if (state.scenes.isEmpty)
                        Text(
                          "No scenes found",
                          style: context.textTheme.bodyMedium?.copyWith(
                            color: ColorsManager.grayColor,
                          ),
                        ),
                      if (state.scenes.isNotEmpty)
                        ConstrainedBox(
                          constraints: BoxConstraints(
                            maxHeight: isSmallScreenSize(context) ? 160 : 170,
                          ),
                          child: ListView.builder(
                            scrollDirection: Axis.horizontal,
                            itemCount: state.scenes.length,
                            itemBuilder: (context, index) => Padding(
                              padding: EdgeInsets.only(
                                right: isSmallScreenSize(context) ? 4.0 : 8.0,
                              ),
                              child: RoutineViewCard(
                                onTap: () {
                                  BlocProvider.of<SwitchTabsBloc>(context).add(
                                    const CreateNewRoutineViewEvent(true),
                                  );
                                  context.read<RoutineBloc>().add(
                                        GetSceneDetails(
                                          sceneId: state.scenes[index].id,
                                          isTabToRun: true,
                                          isUpdate: true,
                                        ),
                                      );
                                },
                                textString: state.scenes[index].name,
                                icon: state.scenes[index].icon ?? Assets.logoHorizontal,
                                isFromScenes: true,
                                iconInBytes: state.scenes[index].iconInBytes,
                              ),
                            ),
                          ),
                        ),
                      const SizedBox(height: 15),
                      Text(
                        "Automations",
                        style: Theme.of(context).textTheme.titleLarge?.copyWith(
                              color: ColorsManager.grayColor,
                              fontWeight: FontWeight.bold,
                            ),
                      ),
                      const SizedBox(height: 10),
                      if (state.automations.isEmpty)
                        Text(
                          "No automations found",
                          style: context.textTheme.bodyMedium?.copyWith(
                            color: ColorsManager.grayColor,
                          ),
                        ),
                      if (state.automations.isNotEmpty)
                        ConstrainedBox(
                          constraints: BoxConstraints(
                            maxHeight: isSmallScreenSize(context) ? 160 : 170,
                          ),
                          child: ListView.builder(
                            scrollDirection: Axis.horizontal,
                            itemCount: state.automations.length,
                            itemBuilder: (context, index) => Padding(
                              padding: EdgeInsets.only(
                                right: isSmallScreenSize(context) ? 4.0 : 8.0,
                              ),
                              child: RoutineViewCard(
                                onTap: () {
                                  BlocProvider.of<SwitchTabsBloc>(context).add(
                                    const CreateNewRoutineViewEvent(true),
                                  );
                                  context.read<RoutineBloc>().add(
                                        GetAutomationDetails(
                                            automationId: state.automations[index].id,
                                            isAutomation: true,
                                            isUpdate: true),
                                      );
                                },
                                textString: state.automations[index].name,
                                icon: state.automations[index].icon ?? Assets.automation,
                              ),
                            ),
                          ),
                        ),
                    ],
                  ),
                ),
              );
      },
    );
  }
}
